@@ -212,8 +212,11 @@ class VariableClAutopartitionDevice(AutopartitionHelper, Variable):
 
     def get(self):
         choiceVal = map(lambda x: x[0], self.choice())
-        if len(choiceVal) == 1:
-            return [choiceVal[0]]
+        devicesTypes = self.Select(['os_device_dev','os_device_type'],
+            where='os_device_dev', _in=choiceVal)
+        notFlashDevices = [x[0] for x in devicesTypes if x[1] != 'flash']
+        if len(notFlashDevices) == 1:
+            return [notFlashDevices[0]]
         return []
 
     def choice(self):
